@@ -54,6 +54,7 @@ def run():
     parser.add_option("-l", "--log", dest="logfile", help="Write debug messages to given logfile")
     parser.add_option("-f", "--file", dest="file", help="Use the given build script")
     parser.add_option("-p", "--patch",action="store_true",  dest="patch", help="Patch closure")
+    parser.add_option("-i", "--info",action="store_true",  dest="info", help="puke task --info show task informations")
 
     (options, args) = parser.parse_args()
 
@@ -201,10 +202,16 @@ def run():
             printTasks()
             sys.exit(1)
 
-    for name in args:
-        if not os.path.basename(name) in pukefiles:
-            executeTask(name.strip())
-        
+    
+    name = args.pop(0)
+
+    if options.info:
+        printHelp(name.strip())
+    else:
+        executeTask(name.strip(), *args)
+            
+
+
 def gettraceback():
     trace = ""
     exception = ""
